@@ -41,7 +41,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.3'; # VERSION
+our $VERSION = 'v0.8.4'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -406,14 +406,17 @@ sub configure {
                 'filename' => 'README',
                 'content'  => [
                     q[{] . q[{],
+                    q[    my @parts;                                                                       ],
                     q[    for my $file ( ] . $self->_quote( $self->readme ) . q[ ) {                       ],
-                    q[        $OUT .=                                                                      ],
+                    q[        push( @parts,                                                                ],
                     q[            include( MY::file( $plugin, $file ) )                                    ],
                     q[                ->fill_in                                                            ],
                     q[                ->pod2text( width => 80, indent => 0, loose => 1, quotes => 'none' ) ],
                     q[                ->chomp .                                                            ],
-                    q[            "\n\n";                                                                  ],
+                    q[            "\n",                                                                    ],
+                    q[        );                                                                           ],
                     q[    };                                                                               ],
+                    q[    join( "\n", @parts );                                                            ],
                     q[}] . q[}],
                 ],
             } ],
@@ -932,7 +935,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.3, released on 2015-09-27 01:12 UTC.
+Version v0.8.4, released on 2015-09-27 08:14 UTC.
 
 =head1 WHAT?
 
